lilypondfiletools.DateTimeToken
===============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken

.. autoclass:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__eq__
      ~abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__format__
      ~abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__ne__
      ~abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.__repr__
   :noindex:
